pub enum EnvFilesConfig {
List(Vec<String>),
TokenFiles(EnvFilesTokenConfig),
}Expand description
Environment file configuration.
Accepts two forms:
- List form (anodizer extension): array of
.envfile paths loaded as KEY=VALUE.env_files: - .env - .release.env - Struct form: paths to files containing provider tokens.
env_files: github_token: ~/.config/goreleaser/github_token gitlab_token: ~/.config/goreleaser/gitlab_token gitea_token: ~/.config/goreleaser/gitea_token
Variants
List(Vec<String>)
List of .env file paths to load (KEY=VALUE format).
TokenFiles(EnvFilesTokenConfig)
Structured token file paths.
Implementations
Sourceimpl EnvFilesConfig
impl EnvFilesConfig
Sourcepub fn as_list(&self) -> Option<&[String]>
pub fn as_list(&self) -> Option<&[String]>
Returns the list of .env file paths if this is the List variant.
Sourcepub fn as_token_files(&self) -> Option<&EnvFilesTokenConfig>
pub fn as_token_files(&self) -> Option<&EnvFilesTokenConfig>
Returns the token files config if this is the TokenFiles variant.