pub enum IncludeSpec {
Path(String),
FromFile {
from_file: IncludeFilePath,
},
FromUrl {
from_url: IncludeUrlConfig,
},
}Expand description
An include specification: either a plain path string or a structured from_file/from_url.
YAML examples:
includes:
- ./defaults.yaml # plain string (backward compat)
- from_file:
path: ./config/goreleaser.yaml # structured file path
- from_url:
url: https://example.com/config.yaml # URL fetch
headers:
x-api-token: "${MYCOMPANY_TOKEN}" # env var expansion in headersVariants
Path(String)
Plain string path (backward compatible): “path/to/file.yaml”
FromFile
Structured file include with from_file.path.
Fields

from_file: IncludeFilePathFromUrl
Structured URL include with from_url.url and optional headers.
Fields

from_url: IncludeUrlConfigTrait Implementations
Sourceimpl Clone for IncludeSpec
impl Clone for IncludeSpec
Sourcefn clone(&self) -> IncludeSpec
fn clone(&self) -> IncludeSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IncludeSpec
impl Debug for IncludeSpec
Sourceimpl<'de> Deserialize<'de> for IncludeSpec
impl<'de> Deserialize<'de> for IncludeSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for IncludeSpec
impl JsonSchema for IncludeSpec
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for IncludeSpec
impl PartialEq for IncludeSpec
Sourcefn eq(&self, other: &IncludeSpec) -> bool
fn eq(&self, other: &IncludeSpec) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for IncludeSpec
impl Serialize for IncludeSpec
impl StructuralPartialEq for IncludeSpec