pub enum WrapInDirectory {
Bool(bool),
Name(String),
}Variants
Implementations
Sourceimpl WrapInDirectory
impl WrapInDirectory
Sourcepub fn directory_name(&self, default_name: &str) -> Option<String>
pub fn directory_name(&self, default_name: &str) -> Option<String>
Resolve the directory name to wrap archive contents in.
When true, uses default_name (typically the archive stem).
When false or an empty string, returns None (no wrapping).
Otherwise returns the custom name.