pub struct BuildOverride {
pub targets: Vec<String>,
pub env: Option<Vec<String>>,
pub flags: Option<Vec<String>>,
pub features: Option<Vec<String>>,
}Expand description
Override env, flags, or features for targets matching glob patterns.
Fields
targets: Vec<String>Glob patterns to match against target triples (e.g., ["x86_64-*", "*-linux-*"]).
env: Option<Vec<String>>Extra environment variables to set for matching targets.
flags: Option<Vec<String>>Extra flags to append for matching targets, one per list entry.
features: Option<Vec<String>>Extra features to enable for matching targets.