pub struct ScmRepoConfig {
pub owner: String,
pub name: String,
pub token: Option<String>,
}Fields
owner: StringRepository owner (user or organization).
name: StringRepository name.
token: Option<String>Auth token override for this repository, instead of the default one. Useful when the release repository requires a different token than the one used to build from — for instance, when publishing to a repository in another organization. Supports templates (environment variables). Unset falls back to the pipeline token.
release:
github:
owner: my-org
name: my-repo
token: "{{ .Env.RELEASE_GITHUB_TOKEN }}"Trait Implementations
Sourceimpl Clone for ScmRepoConfig
impl Clone for ScmRepoConfig
Sourcefn clone(&self) -> ScmRepoConfig
fn clone(&self) -> ScmRepoConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScmRepoConfig
impl Debug for ScmRepoConfig
Sourceimpl<'de> Deserialize<'de> for ScmRepoConfig
impl<'de> Deserialize<'de> for ScmRepoConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScmRepoConfig
impl JsonSchema for ScmRepoConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ScmRepoConfig
impl RefUnwindSafe for ScmRepoConfig
impl Send for ScmRepoConfig
impl Sync for ScmRepoConfig
impl Unpin for ScmRepoConfig
impl UnsafeUnpin for ScmRepoConfig
impl UnwindSafe for ScmRepoConfig