is_deterministic

Function is_deterministic 

pub fn is_deterministic(err: &Error) -> bool
True when any link of the chain is a DeterministicError marker — context layered on top of a marked error does not hide it.