pub struct MakeselfConfig {Show 16 fields
pub id: Option<String>,
pub ids: Option<Vec<String>>,
pub filename: Option<String>,
pub name: Option<String>,
pub script: Option<String>,
pub description: Option<String>,
pub maintainer: Option<String>,
pub keywords: Option<Vec<String>>,
pub homepage: Option<String>,
pub license: Option<String>,
pub compression: Option<String>,
pub extra_args: Option<Vec<String>>,
pub files: Option<Vec<MakeselfFile>>,
pub goos: Option<Vec<String>>,
pub goarch: Option<Vec<String>>,
pub skip: Option<StringOrBool>,
}Fields
id: Option<String>Unique identifier for this makeself config (default: “default”).
ids: Option<Vec<String>>Build IDs filter: only include artifacts whose id is in this list.
filename: Option<String>Output filename template (default includes project, version, os, arch).
name: Option<String>Display name embedded in the self-extracting archive.
script: Option<String>Startup script to run when the archive is extracted and executed. Required — the archive will not be created without this.
description: Option<String>Description for LSM metadata.
maintainer: Option<String>Maintainer for LSM metadata.
keywords: Option<Vec<String>>Keywords for LSM metadata.
homepage: Option<String>Homepage URL for LSM metadata.
license: Option<String>License for LSM metadata.
compression: Option<String>Compression algorithm: gzip, bzip2, xz, lzo, compress, or none.
extra_args: Option<Vec<String>>Extra arguments passed to the makeself command.
files: Option<Vec<MakeselfFile>>Additional files to include in the archive.
goos: Option<Vec<String>>Target OS filter (default: [“linux”, “darwin”]).
goarch: Option<Vec<String>>Target architecture filter.
skip: Option<StringOrBool>Skip this config. Accepts bool or template string.