Skip to main contentCrate anodizer_core
Source - artifact
- config
- context
- env_expand
- Shell-style
$VAR / ${VAR} expansion with a pluggable lookup. - extrafiles
- Shared
extra_files glob resolution. - git
- github_client
- GitHub client trait and mock implementation.
- hashing
- Shared hashing helpers.
- hooks
- http
- HTTP client helpers shared by every stage that talks to a remote.
- log
- Thin structured logging helper for anodizer stages.
- parallel
- Shared bounded-parallelism helper used by stages that run one subprocess
per sub-config (makeself, nfpm, snapcraft, flatpak, upx, …).
- partial
- Partial build target resolution for split/merge CI fan-out.
- pipe_skip
- Aggregated per-stage skip tracking.
- redact
- Secret redaction for command output.
- retry
- Uniform retry-with-exponential-backoff primitives.
- scm
- SCM backend abstraction: token type resolution, download URLs, and release
URL templates for GitHub, GitLab, and Gitea.
- stage
- target
- template
- templated_files
- Shared utility for processing
templated_extra_files across stages. - url
- URL encoding helpers.
- util