ContextOptions

Struct ContextOptions 

pub struct ContextOptions {
Show 17 fields pub snapshot: bool, pub nightly: bool, pub dry_run: bool, pub quiet: bool, pub verbose: bool, pub debug: bool, pub skip_stages: Vec<String>, pub selected_crates: Vec<String>, pub token: Option<String>, pub parallelism: usize, pub single_target: Option<String>, pub release_notes_path: Option<PathBuf>, pub fail_fast: bool, pub partial_target: Option<PartialTarget>, pub merge: bool, pub project_root: Option<PathBuf>, pub strict: bool,
}

Fields

snapshot: boolnightly: booldry_run: boolquiet: boolverbose: booldebug: boolskip_stages: Vec<String>selected_crates: Vec<String>token: Option<String>parallelism: usize

Maximum number of parallel build jobs (minimum 1).

single_target: Option<String>

When set, build only for this single host target triple.

release_notes_path: Option<PathBuf>

Path to a custom release notes file (overrides changelog).

fail_fast: bool

When true, abort immediately on first error during publishing.

partial_target: Option<PartialTarget>

Partial build target for split/merge mode. When set, the build stage filters targets to only those matching this partial target.

merge: bool

When true, running with --merge flag (merging artifacts from split builds).

project_root: Option<PathBuf>

Explicit project root directory. When set, stages use this instead of discovering the repo root via git rev-parse --show-toplevel.

strict: bool

Strict mode: configured features that would silently skip become errors.