pub fn is_deterministic(err: &Error) -> boolExpand description
True when any link of the chain is a DeterministicError marker —
context layered on top of a marked error does not hide it.
pub fn is_deterministic(err: &Error) -> boolTrue when any link of the chain is a DeterministicError marker —
context layered on top of a marked error does not hide it.