pub fn string(input: &str, env: &[(String, String)]) -> StringExpand description
Redact secret values in a string, replacing them with $KEY_NAME.
Longer values are replaced first to prevent partial matches.
Mirrors GoReleaser’s redact.String(s, env) API.